---
name: Bug report
about: Help improve Speckle!
title: ''
labels: bug
assignees: ''
---

<!---

Provide a short summary in the Title above. Examples of good Issue titles:

* "Bug: Error from server when reticulating splines"
* "Bug: Revit crashes when installing connector"

-->

## Prerequisites

<!---

Please answer the following questions before submitting an issue.

-->

- [ ] I read the [contribution guidelines](https://github.com/specklesystems/speckle-server/blob/main/CONTRIBUTING.md)
- [ ] I checked the [documentation](https://speckle.guide/) and found no answer.
- [ ] I checked [existing issues](../issues?q=is%3Aissue) and found no similar issue. <!-- If you do find an existing issue, please show your support by liking it :+1: instead of creating a new issue -->
- [ ] I checked the [community forum](https://speckle.community/) for related discussions and found no answer.
- [ ] I'm reporting the issue to the correct repository (see also [speckle-server](https://github.com/specklesystems/speckle-server), [speckle-sharp](https://github.com/specklesystems/speckle-sharp), [specklepy](https://github.com/specklesystems/specklepy), [speckle-docs](https://github.com/specklesystems/speckle-docs), and [others](https://github.com/orgs/specklesystems/repositories))

## What package are you referring to?

<!---
Is it related to the server (backend) only, or does this bug relate to the frontend, viewer, objectloader or any other package?
-->

## Describe the bug

<!---
A clear and concise description of what the bug is.
-->

## To Reproduce

<!---
Steps to reproduce the behavior:

1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error
-->

## Expected behavior

<!---
A clear and concise description of what you expected to happen.
-->

## Screenshots

<!---
If applicable, add screenshots to help explain your problem.
-->

## System Info

If applicable, please fill in the below details - they help a lot!

### Desktop (please complete the following information):

- OS: [e.g. iOS]
- Browser [e.g. chrome, safari]
- Version [e.g. 22]

### Smartphone (please complete the following information):

- Device: [e.g. iPhone6]
- OS: [e.g. iOS8.1]
- Browser [e.g. stock browser, safari]
- Version [e.g. 22]

## Failure Logs

<!---
Please include any relevant log snippets or files here, or upload as a file.

If including inline, please use markdown code block syntax. https://docs.github.com/en/get-started/writing-on-github/working-with-advanced-formatting/creating-and-highlighting-code-blocks
For example:

```
your log output here
```
-->

## Additional context

<!---
Add any other context about the problem here.
-->

## Proposed Solution (if any)

<!---
Let us know what how you would solve this.
-->

#### Optional: Affected Projects

<!---
Does this issue propagate to other dependencies or dependents? If so, list them here with links!
-->
